@@ -233,36 +233,36 @@ Optionen:
 </translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1030"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1010"/>
         <source>If the option is checked,a primary private mount point will be created in &quot;%1&quot;
 and a secondary publicly accessible &quot;mirror&quot; mount point will be created in &quot;%2&quot;</source>
         <translation>Wenn die Option aktiviert ist, wird in &quot;%1&quot; ein primärer privater Einhängepunkt erstellt
 und ein sekundärer öffentlich zugänglicher &quot;Spiegel&quot;-Einhängepunkt wird in &quot;%2&quot; erstellt</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1041"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1021"/>
         <source>public mount point: </source>
         <translation>öffentlicher Einhängepunkt: </translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1674"/>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1701"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1654"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1681"/>
         <source>Manage Favorites</source>
         <translation>Favoriten verwalten</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1676"/>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1705"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1656"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1685"/>
         <source>Mount All</source>
         <translation>Alle einhängen</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1739"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1719"/>
         <source>about zuluCrypt</source>
         <translation>Über zuluCrypt</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1938"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1918"/>
         <source>hmac plugin.
 
 This plugin generates a key using below formular:
@@ -275,7 +275,7 @@ Diese Erweiterung erzeugt einen Schlüssel mit Hilfe des folgenden Formulars:
 key = hmac(sha256, Passphrase, Schlüsseldateiinhalt)</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1943"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1923"/>
         <source>keykeyfile plugin.
 
 This plugin generates a key using below formular:
@@ -288,7 +288,7 @@ Diese Erweiterung erzeugt einen Schlüssel mit Hilfe des folgenden Formulars:
 Schlüssel = Passphrase + Schlüsseldateiinhalt</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1948"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1928"/>
         <source>gpg plugin.
 
 This plugin retrives a key locked in a gpg file with a symmetric key</source>
@@ -297,7 +297,7 @@ This plugin retrives a key locked in a gpg file with a symmetric key</source>
 Diese Erweiterung stellt einen Schlüssel wieder her, der in einer gpg-Datei mit einem symmetrischen Schlüssel gesperrt ist</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="2663"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="2678"/>
         <source>Failed To Start Helper Application.
 
 &quot;org.zulucrypt.zulupolkit.policy&quot; polkit file is misconfigured,
@@ -311,8 +311,8 @@ ausführbare Datei zuluPolkit konnte nicht gefunden werden
     </message>
     <message>
         <location filename="../../zuluCrypt-gui/utility.cpp" line="400"/>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1173"/>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1966"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1153"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1946"/>
         <location filename="../../zuluMount-gui/zulumount.cpp" line="911"/>
         <location filename="../../zuluMount-gui/zulumount.cpp" line="927"/>
         <source>ERROR</source>
@@ -324,12 +324,12 @@ ausführbare Datei zuluPolkit konnte nicht gefunden werden
         <translation>Die ausführbare Datei pkexec konnte nicht gefunden werden</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1172"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1152"/>
         <source>&quot;%1&quot; and &quot;%2&quot; Folders Must Be Writable.</source>
         <translation>Die Ordner &quot;%1&quot; und &quot;%2&quot; müssen beschreibbar sein.</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.cpp" line="1966"/>
+        <location filename="../../zuluCrypt-gui/utility.cpp" line="1946"/>
         <source>Could not find &quot;gpg&quot; executable in &quot;/usr/local/bin&quot;,&quot;/usr/bin&quot; and &quot;/usr/sbin&quot;</source>
         <translation>Die ausführbare Datei &quot;gpg&quot; konnte nicht in &quot;/usr/local/bin&quot;, &quot;/usr/bin&quot; und &quot;/usr/sbin&quot; gefunden werden</translation>
     </message>
@@ -392,37 +392,6 @@ ausführbare Datei zuluPolkit konnte nicht gefunden werden
         <translation>Der Wert konnte nicht nur in Ziffern umgewandelt werden </translation>
     </message>
 </context>
-<context>
-    <name>deviceOffset</name>
-    <message>
-        <source>location could be in sectors if the entry is made up of only digits
-or in bytes if the entry ends with &quot;b&quot;
-or in kilobytes if the entry ends with &quot;k&quot;
-or in megabytes if the entry ends with &quot;m&quot;
-or in terabytes if the entry ends with &quot;t&quot;</source>
-        <translation type="vanished">Position könnte in Sektoren sein, wenn die Eingabe nur aus Ziffern besteht
-oder in Byte, wenn der Eintrag mit &quot;b&quot; endet
-oder in Kilobyte, wenn der Eintrag mit &quot;k&quot; endet
-oder in Megabyte, wenn der Eintrag mit &quot;m&quot; endet
-oder in Terabyte, wenn der Eintrag mit &quot;t&quot; endet</translation>
-    </message>
-    <message>
-        <source>Enter Below The Offset Location Of The Volume About To Be Opened.</source>
-        <translation type="vanished">Geben Sie unten die Offset-Position des zu öffnenden Volumes ein.</translation>
-    </message>
-    <message>
-        <source>Enter The Password Below To A Volume At The Above Offset.</source>
-        <translation type="vanished">Geben Sie unten das Passwort eines Volumes mit dem obigen Offset ein.</translation>
-    </message>
-    <message>
-        <source>&amp;Ok</source>
-        <translation type="vanished">&amp;OK</translation>
-    </message>
-    <message>
-        <source>&amp;Cancel</source>
-        <translation type="vanished">Abbre&amp;chen</translation>
-    </message>
-</context>
 <context>
     <name>keyDialog</name>
     <message>
@@ -442,8 +411,8 @@ oder in Terabyte, wenn der Eintrag mit &quot;t&quot; endet</translation>
     </message>
     <message>
         <location filename="../../zuluMount-gui/keydialog.ui" line="58"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="175"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="942"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="171"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="910"/>
         <source>Key</source>
         <translation>Schlüssel</translation>
     </message>
@@ -503,201 +472,173 @@ oder in Terabyte, wenn der Eintrag mit &quot;t&quot; endet</translation>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="76"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="72"/>
         <source>Mount A LUKS volume in &quot;%1&quot;</source>
         <translation>Ein LUKS-Volume in &quot;%1&quot; einhängen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="78"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="74"/>
         <source>Mount An Encrypted Volume In &quot;%1&quot;</source>
         <translation>Ein verschlüsseltes Volume in &quot;%1&quot; einhängen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="81"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="77"/>
         <source>Check This Box To Make Password Visible</source>
         <translation>Aktivieren Sie dieses Kontrollkästchen, um das Passwort sichtbar zu machen</translation>
     </message>
     <message>
-        <source>Set File System Options</source>
-        <translation type="vanished">Dateisystemoptionen festlegen</translation>
-    </message>
-    <message>
-        <source>Set Volume Offset</source>
-        <translation type="vanished">Volume-Offset festlegen</translation>
-    </message>
-    <message>
-        <source>Set VeraCrypt PIM value</source>
-        <translation type="vanished">VeraCrypt PIM-Wert festlegen</translation>
-    </message>
-    <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="176"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="172"/>
         <source>KeyFile</source>
         <translation>Schlüsseldatei</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="177"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="925"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="173"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="885"/>
         <source>Key+KeyFile</source>
         <translation>Schlüssel+Schlüsseldatei</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="178"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="174"/>
         <source>Plugin</source>
         <translation>Erweiterung</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="184"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="967"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="180"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="935"/>
         <source>TrueCrypt/VeraCrypt Keys</source>
         <translation>TrueCrypt/VeraCrypt-Schlüssel</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="187"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="183"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="864"/>
         <source>YubiKey Challenge/Response</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Set Volume As VeraCrypt Volume</source>
-        <translation type="vanished">Volume als VeraCrypt-Volume festlegen</translation>
-    </message>
-    <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="221"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="217"/>
         <source>Select A Folder To Create A Mount Point In</source>
         <translation>Wählen Sie einen Ordner aus, in dem ein Einhängepunkt erstellt werden soll</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="317"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="313"/>
         <source>Select A File To Be Used As A Keyfile</source>
         <translation>Wählen Sie eine Datei aus, die als Schlüsseldatei verwendet werden soll</translation>
     </message>
     <message>
         <location filename="../../zuluMount-gui/keydialog.ui" line="380"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="350"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="361"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="347"/>
         <source>Cancel</source>
         <translation>Abbrechen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="398"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="989"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="957"/>
         <source>ERROR!</source>
         <translation>FEHLER!</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="398"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="989"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="957"/>
         <source>Internal wallet is not configured</source>
         <translation>Interne Brieftasche ist nicht konfiguriert</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="417"/>
-        <source>ERROR</source>
-        <translation>FEHLER</translation>
-    </message>
-    <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="417"/>
-        <source>The volume does not appear to have an entry in the wallet</source>
-        <translation>Das Volume scheint keinen Eintrag in der Brieftasche zu haben</translation>
-    </message>
-    <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="441"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="378"/>
         <source>Atleast one required field is empty</source>
         <translation>Mindestens ein erforderliches Feld ist leer</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="461"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="398"/>
         <source>Failed to unlock a cryfs volume.
 Wrong password entered</source>
         <translation>cryfs-Volume konnte nicht aufgeschlossen werden.
 Falsches Passwort eingegeben</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="466"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="403"/>
         <source>Failed to unlock an encfs volume.
 Wrong password entered</source>
         <translation>encfs-Volume konnte nicht aufgeschlossen werden.
 Falsches Passwort eingegeben</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="471"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="408"/>
         <source>Failed to unlock a gocryptfs volume.
 Wrong password entered</source>
         <translation>gocryptfs-Volume konnte nicht aufgeschlossen werden.
 Falsches Passwort eingegeben</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="476"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="413"/>
         <source>Failed to unlock an ecryptfs volume.
 Wrong password entered</source>
         <translation>ecryptfs-Volume konnte nicht aufgeschlossen werden.
 Falsches Passwort eingegeben</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="481"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="418"/>
         <source>A Space Character Is Not Allowed In Paths When Using Ecryptfs Backend And Polkit</source>
         <translation>Ein Leerzeichen in Pfaden ist nicht erlaubt, wenn ein Ecryptfs Backend und Polkit verwendet werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="486"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="423"/>
         <source>Failed to unlock a securefs volume.
 Wrong password entered</source>
         <translation>securefs-Volume konnte nicht aufgeschlossen werden.
 Falsches Passwort eingegeben</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="491"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="428"/>
         <source>Failed to unlock a cryfs volume.
 cryfs executable could not be found</source>
         <translation>cryfs-Volume konnte nicht aufgeschlossen werden.
 Die ausführbare Datei cryfs konnte nicht gefunden werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="496"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="433"/>
         <source>Failed to unlock a securefs volume.
 securefs executable could not be found</source>
         <translation>securefs-Volume konnte nicht aufgeschlossen werden.
 Die ausführbare Datei securefs konnte nicht gefunden werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="501"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="438"/>
         <source>Failed to unlock a gocryptfs volume.
 gocryptfs executable could not be found</source>
         <translation>gocryptfs-Volume konnte nicht aufgeschlossen werden.
 Die ausführbare Datei gocryptfs konnte nicht gefunden werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="506"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="443"/>
         <source>Failed to unlock an encfs volume.
 encfs executable could not be found</source>
         <translation>encfs-Volume konnte nicht aufgeschlossen werden.
 Die ausführbare Datei encfs konnte nicht gefunden werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="511"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="448"/>
         <source>Failed to unlock an ecryptfs volume.
 ecryptfs-simple executable could not be found</source>
         <translation>ecryptfs-Volume konnte nicht aufgeschlossen werden.
 Die ausführbare Datei ecryptfs konnte nicht gefunden werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="516"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="453"/>
         <source>Failed to create mount point</source>
         <translation>Einhängepunkt konnte nicht erstellt werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="521"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="458"/>
         <source>Failed to unlock the volume.
 Not supported volume encountered</source>
         <translation>Volume konnte nicht aufgeschlossen werden.
 Nicht unterstütztes Volume gefunden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="526"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="463"/>
         <source>This backend requires root&apos;s privileges and an attempt to acquire them has failed.</source>
         <translation>Dieses Backend benötigt die Rechte von root und ein Versuch, sie zu erwerben, ist fehlgeschlagen.</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="531"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="468"/>
         <source>zuluMount Can Not Unlock This Volume Because Its FileSystem Has To Manually Be Converted To The Version Of Cryfs That Is Currently In Use.
 
 Run Cryfs With This Volume To Manually Update This Volume&apos;s FileSystem.</source>
@@ -706,112 +647,112 @@ Run Cryfs With This Volume To Manually Update This Volume&apos;s FileSystem.</so
 Führen Sie Cryfs mit diesem Volume aus, um das Dateisystem dieses Volumes manuell zu aktualisieren.</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="558"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="495"/>
         <source>Failed to mount ntfs/exfat file system using ntfs-3g,is ntfs-3g/exfat package installed?</source>
         <translation>Konnte das NTFS/EXFAT-Dateisystem mit ntfs-3g nicht einhängen, ist das ntfs-3g-Paket installiert?</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="559"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="496"/>
         <source>There seem to be an open volume accociated with given address</source>
         <translation>Es scheint ein geöffnetes Volumen zu geben, das mit der angegebenen Adresse verknüpft ist</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="560"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="497"/>
         <source>No file or device exist on given path</source>
         <translation>Es existiert keine Datei oder Gerät am angegebenen Pfad</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="561"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="498"/>
         <source>Volume could not be opened with the presented key</source>
         <translation>Das Volume konnte nicht mit dem eingegebenen Schlüssel geöffnet werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="562"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="499"/>
         <source>Insufficient privilege to mount the device with given options</source>
         <translation>Unzureichende Rechte zum Einhängen des Geräts mit den angegebenen Optionen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="563"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="500"/>
         <source>Insufficient privilege to open device in read write mode or device does not exist</source>
         <translation>Unzureichende Rechte zum Öffnen des Geräts im Schreib-/Lesemodus oder das Gerät existiert nicht</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="564"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="501"/>
         <source>Only root user can perform this operation</source>
         <translation>Nur root kann diese Operation ausführen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="565"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="502"/>
         <source>-O and -m options can not be used together</source>
         <translation>Die Optionen -O und -m können nicht zusammen verwendet werden</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="566"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="503"/>
         <source>Could not create mount point, invalid path or path already taken</source>
         <translation>Es konnte kein Einhängepunkt erstellt werden, ungültiger Pfad oder bereits belegter Pfad</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="567"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="504"/>
         <source>Shared mount point path aleady taken</source>
         <translation>Der gemeinsame Einhängepunktpfad ist bereits vergeben</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="568"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="505"/>
         <source>There seem to be an opened mapper associated with the device</source>
         <translation>Es scheint ein geöffneter Mapper mit dem Gerät assoziiert zu sein</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="569"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="506"/>
         <source>Could not get a passphrase from the module</source>
         <translation>Konnte keine Passphrase von dem Modul erhalten</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="570"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="507"/>
         <source>Could not get passphrase in silent mode</source>
         <translation>Konnte die Passphrase nicht im stillen Modus bekommen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="571"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="508"/>
         <source>Insufficient memory to hold passphrase</source>
         <translation>Nicht genügend Speicherplatz zum Speichern der Passphrase</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="572"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="509"/>
         <source>One or more required argument(s) for this operation is missing</source>
         <translation>Ein oder mehrere für diese Operation erforderlichen Argument(e) fehlt/fehlen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="573"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="510"/>
         <source>Invalid path to key file</source>
         <translation>Ungültiger Pfad zur Schlüsseldatei</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="574"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="511"/>
         <source>Could not get enought memory to hold the key file</source>
         <translation>Konnte nicht genug Speicher zum Halten der Schlüsseldatei bekommen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="575"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="512"/>
         <source>Insufficient privilege to open key file for reading</source>
         <translation>Unzureichende Rechte zum Öffnen der Schlüsseldatei für das Lesen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="576"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="513"/>
         <source>Could not get a passphrase through a local socket</source>
         <translation>Konnte keine Passphrase über den lokalen Socket erhalten</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="577"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="514"/>
         <source>Failed to mount a filesystem:invalid/unsupported mount option or unsupported file system encountered</source>
         <translation>Konnte kein Dateisystem einhängen: ungültige/nicht unterstützte Einhängeoption oder nicht unterstütztes Dateisystem entdeckt</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="578"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="515"/>
         <source>Could not create a lock on /etc/mtab</source>
         <translation>Konnte keine Sperre für /etc/mtab erstellen</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="579"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="516"/>
         <source>Insufficient privilege to open a system volume.
 
 Consult menu-&gt;help-&gt;permission for more informaion
@@ -822,7 +763,7 @@ Siehe Menü-&gt;Hilfe-&gt;Berechtigung für weitere Informationen
 </translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="580"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="517"/>
         <source>A non supported device encountered,device is missing or permission denied
 Possible reasons for getting the error are:
 1.Device path is invalid.
@@ -833,62 +774,44 @@ Mögliche Gründe für diesen Fehler sind:
 2. Das Gerät hat eine LVM oder MD-RAID Signatur</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="627"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="580"/>
         <source>Plug in name field is empty</source>
         <translation>Feld Erweiterungsname ist leer</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="635"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="588"/>
         <source>Keyfile field is empty</source>
         <translation>Das Feld Schlüsseldatei ist leer</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="667"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="568"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="620"/>
         <source>Failed To Locate Or Run Yubikey&apos;s &quot;ykchalresp&quot; Program.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="867"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="820"/>
         <source>ERROR: </source>
         <translation>FEHLER: </translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="922"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="882"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="892"/>
         <location filename="../../zuluMount-gui/keydialog.cpp" line="932"/>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="964"/>
         <source>Plugin name</source>
         <translation>Erweiterungsname</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="953"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="921"/>
         <source>Keyfile path</source>
         <translation>Pfad zur Schlüsseldatei</translation>
     </message>
     <message>
-        <location filename="../../zuluMount-gui/keydialog.cpp" line="647"/>
+        <location filename="../../zuluMount-gui/keydialog.cpp" line="600"/>
         <source>&quot;/&quot; character is not allowed in the mount name field</source>
         <translation>Das Zeichen &quot;/&quot; ist im Namensfeld nicht erlaubt</translation>
     </message>
 </context>
-<context>
-    <name>mountOptions</name>
-    <message>
-        <source>file system options</source>
-        <translation type="vanished">Dateisystemoptionen</translation>
-    </message>
-    <message>
-        <source>&amp;Ok</source>
-        <translation type="vanished">&amp;OK</translation>
-    </message>
-    <message>
-        <source>&amp;Cancel</source>
-        <translation type="vanished">Abbre&amp;chen</translation>
-    </message>
-    <message>
-        <source>Enter Comma Separated Volume&apos;s File System Options Below</source>
-        <translation type="vanished">Geben Sie unten die kommagetrennten Dateisystemoptionen des Volumes ein</translation>
-    </message>
-</context>
 <context>
     <name>mountPartition</name>
     <message>
@@ -966,14 +889,6 @@ Mögliche Gründe für diesen Fehler sind:
         <source>Set File System Options</source>
         <translation>Dateisystemoptionen festlegen</translation>
     </message>
-    <message>
-        <source>Set Volume Offset</source>
-        <translation type="vanished">Volume-Offset festlegen</translation>
-    </message>
-    <message>
-        <source>ERROR!</source>
-        <translation type="vanished">FEHLER!</translation>
-    </message>
     <message>
         <location filename="../../zuluMount-gui/mountpartition.cpp" line="156"/>
         <source>Could not resolve path to device or device could not be opened in read write mode</source>
@@ -1088,22 +1003,22 @@ Notwendige Berechtigungen können erworben werden durch:
 <context>
     <name>utility::veraCryptWarning</name>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="876"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="880"/>
         <source>Elapsed time: 0 seconds</source>
         <translation>Vergangene Zeit: 0 Sekunden</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="884"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="888"/>
         <source>Elapsed time: %0 minutes</source>
         <translation>Vergangene Zeit: %0 Minuten</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="886"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="890"/>
         <source>Elapsed time: %0 seconds</source>
         <translation>Vergangene Zeit: %0Sekunden</translation>
     </message>
     <message>
-        <location filename="../../zuluCrypt-gui/utility.h" line="897"/>
+        <location filename="../../zuluCrypt-gui/utility.h" line="901"/>
         <source>Please be patient as unlocking a VeraCrypt volume may take a very long time.
 
 </source>
@@ -1214,10 +1129,6 @@ Notwendige Berechtigungen können erworben werden durch:
         <source>Select Icons</source>
         <translation>Symbole auswählen</translation>
     </message>
-    <message>
-        <source>Check For Update</source>
-        <translation type="vanished">Auf Aktualisierungen prüfen</translation>
-    </message>
     <message>
         <location filename="../../zuluMount-gui/zulumount.cpp" line="350"/>
         <source>About</source>
