@@ -203,6 +203,31 @@ static int zuluCryptEXECheckEmptySlots( const char * device )
 	return status ;
 }
 
+static int zuluCryptEXEPrintSlotStatus( const char * device )
+{
+	int status ;
+	char * c  ;
+	zuluCryptSecurityGainElevatedPrivileges() ;
+	/*
+	 * zuluCryptEmptySlots() is defined in ../lib/empty_slots.c
+	 */
+	c = zuluCryptSlotsStatus( device ) ;
+
+	zuluCryptSecurityDropElevatedPrivileges() ;
+
+	if( c == NULL ){
+
+		printf( gettext( "Device \"%s\" is not a luks device\n" ),device ) ;
+		status = 2 ;
+	}else{
+		printf( "%s",c ) ;
+		status = 0 ;
+		free( c ) ;
+	}
+
+	return status ;
+}
+
 static int zuluCryptEXECheckUUID( const char * device )
 {
 	printf( "%s\n",device ) ;
@@ -250,6 +275,7 @@ static int zuluCryptEXE( struct_opts * clargs,const char * mapping_name,uid_t ui
 		case 'X' : return zuluCryptEXEWriteDeviceWithJunk( clargs,mapping_name,uid ) ;
 		case 'w' : return zuluCryptEXECheckUUID( clargs->device ) ;
 		case 'b' : return zuluCryptEXECheckEmptySlots( clargs->device ) ;
+		case '2' : return zuluCryptEXEPrintSlotStatus( clargs->device ) ;
 		case 'i' : return zuluCryptEXECheckIfLuks( clargs->device ) ;
 		case 'P' : return zuluCryptEXEGetDevice( clargs->device ) ;
 		case 's' : return zuluCryptEXEVolumeInfo( mapping_name,clargs->device,uid ) ;
@@ -267,7 +293,7 @@ static int zuluCryptEXE( struct_opts * clargs,const char * mapping_name,uid_t ui
 	return 200 ; /* shouldnt get here */
 }
 
-static int zuluExit( int st,stringList_t stl,stringList_t stx,char * const * env,const char * msg )
+static int zuluExit( int st,stringList_t stl,stringList_t stx,const char ** env,const char * msg )
 {
 	zuluCryptSecurityUnlockMemory( stl ) ;
 	StringListClearDelete( &stl ) ;
@@ -361,7 +387,7 @@ int main( int argc,char * argv[] )
 	char * dev ;
 	char action ;
 	int st ;
-	char * const * env = NULL ;
+	const char ** env = NULL ;
 	ssize_t i ;
 
 	string_t q = StringVoid ;
@@ -379,6 +405,34 @@ int main( int argc,char * argv[] )
 	sa.sa_handler = _forceTerminateOnSeriousError ;
 	sigaction( SIGSEGV,&sa,NULL ) ;
 
+	if( argc == 1 ){
+
+		zuluCryptEXEHelp();
+		return 1;
+	}
+	if( argc == 2 ){
+
+		ac = argv[ 1 ] ;
+
+		if( StringAtLeastOneMatch_1( ac,"-h","--help","-help",NULL ) ){
+
+			zuluCryptEXEHelp();
+
+			return 0 ;
+		}
+		if( StringAtLeastOneMatch_1( ac,"-v","-version","--version",NULL ) ){
+
+			printf( "%s\n",zuluCryptVersion() );
+
+			return 0 ;
+		}
+		if( StringsAreEqual( ac,"--clear-dead-mount-points" ) ){
+
+			zuluCryptClearDeadMappers( uid,1 ) ;
+			return 0 ;
+		}
+	}
+
 	zuluCryptExeSetOriginalUID( uid ) ;
 
 	/*
@@ -429,7 +483,7 @@ int main( int argc,char * argv[] )
 		printf( gettext( "User is not root\n" ) ) ;
 		return 114 ;
 	}else{
-		uid = st ;
+		uid = (uid_t)st ;
 	}
 
 	/*
@@ -461,34 +515,6 @@ int main( int argc,char * argv[] )
 	 */
 	zuluCryptSecurityDropElevatedPrivileges() ;
 
-	if( argc == 1 ){
-
-		zuluCryptEXEHelp();
-		return 1;
-	}
-	if( argc == 2 ){
-
-		ac = argv[ 1 ] ;
-
-		if( StringAtLeastOneMatch_1( ac,"-h","--help","-help",NULL ) ){
-
-			zuluCryptEXEHelp();
-
-			return 0 ;
-		}
-		if( StringAtLeastOneMatch_1( ac,"-v","-version","--version",NULL ) ){
-
-			printf( "%s\n",zuluCryptVersion() );
-
-			return 0 ;
-		}
-		if( StringsAreEqual( ac,"--clear-dead-mount-points" ) ){
-
-			zuluCryptClearDeadMappers( uid,1 ) ;
-			return 0 ;
-		}
-	}
-
 	/*
 	 * this object is used as a form of memory management.It collects all string objects to make them easily deletable
 	 * at the end of the function and allows a function to have easily managebale multiple exit points.
@@ -528,7 +554,7 @@ int main( int argc,char * argv[] )
 	 * Hide "sensitive" command line arguments from ps comamnd and related tools.
 	 * Best way to pass keys to zuluCrypt-cli is to use libzuluCryptPluginManager API
 	 */
-	#define hide( z ) strncpy( ( char * )z,"x",StringLength( q ) ) ;
+	#define hide( z ) strncpy( ( char * )z,"x",StringLength( q ) )
 
 	if( clargs.key != NULL ){
 
