@@ -38,15 +38,23 @@ typedef struct arguments{
 	const char * algo ;
 	const char * cipher ;
 	const char * rng ;
+	const char * label ;
+	const char * subsystem ;
 	const char * integrity ;
-
+	const char * pbkdf_type ;
+	const char * pbkdf_memory ;
+	const char * pbkdf_threads ;
 	void * params ;
 	void * pbkdf ;
 
-	u_int64_t iterations ;
+	unsigned int time_ms ;
+	unsigned int iterations ;
+
+	int allowDiscard ;
 
 	void *( *function )( const struct arguments * ) ;
 	int ( *format )( struct crypt_device * ) ;
+	void ( *set_persistent_flags )( const struct arguments *,struct crypt_device * cd ) ;
 
 }arguments ;
 
@@ -159,9 +167,9 @@ static int _create_luks( const char * device,const resolve_path_t * opts )
 		crypt_set_rng_type( cd,CRYPT_RNG_URANDOM ) ;
 	}
 
-	if( args->iterations != 0 && StringsAreEqual( args->type,CRYPT_LUKS1 )){
+	if( args->time_ms != 0 && StringsAreEqual( args->type,CRYPT_LUKS1 )){
 
-		crypt_set_iteration_time( cd,args->iterations ) ;
+		crypt_set_iteration_time( cd,args->time_ms ) ;
 	}
 
 	if( crypt_format( cd,args->type,args->algo,args->cipher,NULL,NULL,
@@ -170,6 +178,8 @@ static int _create_luks( const char * device,const resolve_path_t * opts )
 		return zuluExit_1( 2,cd ) ;
 	}
 
+	args->set_persistent_flags( args,cd ) ;
+
 	if( crypt_keyslot_add_by_volume_key( cd,CRYPT_ANY_SLOT,NULL,args->key_size,
 		args->key,args->key_len ) < 0 ){
 		return zuluExit_1( 3,cd ) ;
@@ -202,6 +212,8 @@ static int _create_luks_0( arguments * args,const char * device,const char * key
 
 	stringList_t stl ;
 
+	const char * m ;
+
 	/*
 	 * options is structure expected to be in a format of:
 	 * rng.algo.cipher.keysize.hash.iteration_count
@@ -233,17 +245,94 @@ static int _create_luks_0( arguments * args,const char * device,const char * key
 			args->rng      = *( list + 0 ) ;
 			args->algo     = *( list + 1 ) ;
 			args->cipher   = *( list + 2 ) ;
-			args->key_size = ( size_t ) StringConvertToInt( *( list + 3 ) ) / 8 ;
+			args->key_size = ( unsigned long ) StringConvertToInt( *( list + 3 ) ) / 8 ;
 			args->hash     = *( list + 4 ) ;
 
 			if( list_count > 5 ){
 
-				args->iterations = StringConvertToInt( *( list + 5 ) ) ;
+				m = *( list + 5 ) ;
+
+				if( StringsAreNotEqual( m,"-1" ) ){
+
+					args->time_ms = ( unsigned int ) StringConvertToInt( m ) ;
+				}
 			}
 
 			if( list_count > 6 ){
 
-				args->integrity = *( list + 6 ) ;
+				m = *( list + 6 ) ;
+
+				if( StringsAreNotEqual( m,"-1" ) ){
+
+					args->iterations = ( unsigned int ) StringConvertToInt( m ) ;
+				}
+			}
+
+			if( list_count > 7 ){
+
+				m = *( list + 7 ) ;
+
+				if( StringsAreNotEqual( m,"null" ) ){
+
+					args->integrity = m ;
+				}
+			}
+
+			if( list_count > 8 ){
+
+				m = *( list + 8 ) ;
+
+				if( StringsAreNotEqual( m,"null" ) ){
+
+					args->pbkdf_type = m ;
+				}
+			}
+
+			if( list_count > 9 ){
+
+				m = *( list + 9 ) ;
+
+				if( StringsAreNotEqual( m,"-1" ) ){
+
+					args->pbkdf_memory = m ;
+				}
+			}
+
+			if( list_count > 10 ){
+
+				m = *( list + 10 ) ;
+
+				if( StringsAreNotEqual( m,"-1" ) ){
+
+					args->pbkdf_threads = m ;
+				}
+			}
+
+			if( list_count > 11 ){
+
+				m = *( list + 11 ) ;
+
+				if( StringsAreNotEqual( m,"null" ) ){
+
+					args->label = m ;
+				}
+			}
+
+			if( list_count > 12 ){
+
+				m = *( list + 12 ) ;
+
+				if( StringsAreNotEqual( m,"null" ) ){
+
+					args->subsystem = m ;
+				}
+			}
+
+			if( list_count > 13 ){
+
+				m = *( list + 13 ) ;
+
+				args->allowDiscard = ( int ) StringConvertToInt( m ) ;
 			}
 		}
 	}else{
@@ -281,6 +370,10 @@ static int _format_0( struct crypt_device * cd )
 	if( cd ){}
 	return 0 ;
 }
+static void _set_persistent_flags_0( const arguments * args,struct crypt_device * cd )
+{
+	if( args && cd ){}
+}
 
 int zuluCryptCreateLuks( const char * device,const char * key,size_t key_len,const char * options )
 {
@@ -295,6 +388,7 @@ int zuluCryptCreateLuks( const char * device,const char * key,size_t key_len,con
 	args.function = _luks1 ;
 	args.type     = CRYPT_LUKS1 ;
 	args.format   = _format_0 ;
+	args.set_persistent_flags = _set_persistent_flags_0 ;
 
 	return _create_luks_0( &args,device,key,key_len,options ) ;
 }
@@ -369,6 +463,14 @@ static int _format( struct crypt_device * cd )
 	return 0 ;
 }
 
+static void _set_persistent_flags( const arguments * args,struct crypt_device * cd )
+{
+	if( args->allowDiscard ){
+
+		crypt_persistent_flags_set( cd,CRYPT_FLAGS_ACTIVATION,CRYPT_ACTIVATE_ALLOW_DISCARDS ) ;
+	}
+}
+
 void zuluCryptDisableMetadataLocking( void )
 {
 	crypt_metadata_locking( NULL,0 ) ;
@@ -382,6 +484,8 @@ static void * _luks2( const arguments * args )
 
 	params->sector_size     = 512 ;
 	params->integrity       = args->integrity ;
+	params->label           = args->label ;
+	params->subsystem       = args->subsystem ;
 
 #if SUPPORT_crypt_get_pbkdf_default
 	/*
@@ -393,13 +497,41 @@ static void * _luks2( const arguments * args )
 	pbkdf->max_memory_kb    = 1024 ;
 	pbkdf->parallel_threads = 4 ;
 #endif
-	pbkdf->hash = args->hash ;
+	if( StringsAreNotEqual( args->pbkdf_type,"pbkdf2" ) ){
+
+		if( args->pbkdf_memory ){
+
+			pbkdf->max_memory_kb = ( unsigned int ) StringConvertToInt( args->pbkdf_memory ) ;
+		}
+
+		if( args->pbkdf_threads ){
+
+			pbkdf->parallel_threads = ( unsigned int ) StringConvertToInt( args->pbkdf_threads ) ;
+		}
+	}else{
+		pbkdf->max_memory_kb = 0 ;
+		pbkdf->parallel_threads = 0 ;
+	}
+
+	if( args->time_ms != 0 ){
+
+		pbkdf->time_ms = args->time_ms ;
+	}
 
 	if( args->iterations != 0 ){
 
-		pbkdf->time_ms = (unsigned int)args->iterations ;
+		pbkdf->time_ms = 0 ;
+		pbkdf->iterations = args->iterations ;
+		pbkdf->flags |= CRYPT_PBKDF_NO_BENCHMARK ;
 	}
 
+	if( args->pbkdf_type ){
+
+		pbkdf->type = args->pbkdf_type ;
+	}
+
+	pbkdf->hash = args->hash ;
+
 	params->pbkdf = pbkdf ;
 
 	return params ;
@@ -421,6 +553,7 @@ int zuluCryptCreateLuks2( const char * device,const char * key,size_t key_len,co
 	args.function = _luks2 ;
 	args.type     = CRYPT_LUKS2 ;
 	args.format   = _format ;
+	args.set_persistent_flags = _set_persistent_flags ;
 
 	return _create_luks_0( &args,device,key,key_len,options ) ;
 }
