@@ -54,7 +54,8 @@ createfile::createfile( QWidget * parent,std::function< void( const QString& ) >
 	connect( m_ui->pbCreate,SIGNAL( clicked() ),this,SLOT( pbCreate() ) ) ;
 	connect( m_ui->lineEditFileName,SIGNAL( textChanged( QString ) ),this,SLOT(fileTextChange( QString ) ) ) ;
 
-	connect( this,SIGNAL( sendProgress( int ) ),this,SLOT( setProgress( int ) ) ) ;
+	connect( this,SIGNAL( sendProgress( QString,QString,QString,QString,int ) ),
+		 this,SLOT( setProgress( QString,QString,QString,QString,int ) ) ) ;
 
 	this->installEventFilter( this ) ;
 
@@ -225,7 +226,7 @@ void createfile::pbCreate()
 
 	this->disableAll() ;
 
-	emit sendProgress( 0 ) ;
+	m_ui->progressBar->setValue( 0 ) ;
 
 	m_exit = false ;
 
@@ -278,7 +279,16 @@ void createfile::pbCreate()
 
 			file.close() ;
 
-			int r = utility::clearVolume( filePath,&m_exit,0,[ this ]( int i ){ emit sendProgress( i ) ; } ).await() ;
+			utility::progress update( 1500,[ this ]( const utility::progress::result& m ){
+
+				emit sendProgress( m.current_speed,
+						   m.average_speed,
+						   m.eta,
+						   m.total_time,
+						   m.percentage_done ) ;
+			} ) ;
+
+			int r = utility::clearVolume( filePath,&m_exit,0,update.updater_quint() ).await() ;
 
 			if( r == 5 ){
 
@@ -304,15 +314,17 @@ void createfile::pbCreate()
 
 void createfile::createFile( const QString& filePath,qint64 size )
 {
-	int i = 0 ;
-	int j = 0 ;
-
-	std::array< char,1024 > buffer ;
-
-	qint64 size_written = 0 ;
-
 	enum class result{ success,deviceFail,cancelled,fileFail } ;
 
+	utility::progress update( 1500,[ this ]( const utility::progress::result& m ){
+
+		emit sendProgress( m.current_speed,
+				   m.average_speed,
+				   m.eta,
+				   m.total_time,
+				   m.percentage_done ) ;
+	} ) ;
+
 	auto s = Task::await( [ & ]{
 
 		auto rd = utility::RandomDataSource::get() ;
@@ -329,6 +341,12 @@ void createfile::createFile( const QString& filePath,qint64 size )
 			return result::fileFail ;
 		}
 
+		auto function = update.updater_qint() ;
+
+		std::array< char,1024 > buffer ;
+
+		qint64 size_written = 0 ;
+
 		while( size_written < size ){
 
 			if( m_exit ){
@@ -337,25 +355,27 @@ void createfile::createFile( const QString& filePath,qint64 size )
 			}else{
 				auto s = rd->getData( buffer.data(),buffer.size() ) ;
 
-				size_written += file.write( buffer.data(),s ) ;
+				auto m =  file.write( buffer.data(),s ) ;
 
-				i = int( ( size_written * 100 / size ) ) ;
+				if( m == -1 ){
 
-				if( i > j ){
-
-					emit sendProgress( i ) ;
-
-					j = i ;
+					//WTF!!
 				}
+
+				file.flush() ;
+
+				size_written += m ;
+
+				function( size,size_written ) ;
 			}
 		}
 
 		file.resize( size ) ;
 
-		return  result::success ;
+		return result::success ;
 	} ) ;
 
-	switch ( s ) {
+	switch( s ) {
 		case result::success :
 		m_function( filePath ) ;
 		break ;
@@ -395,9 +415,17 @@ void createfile::HideUI()
 	this->deleteLater() ;
 }
 
-void createfile::setProgress( int p )
+void createfile::setProgress( QString cs,QString av,QString eta,QString tt,int st )
 {
-	m_ui->progressBar->setValue( p ) ;
+	Q_UNUSED( cs )
+	Q_UNUSED( tt )
+
+	QString a = tr( "Average Speed:" ) + " " + av ;
+	QString b = tr( "ETA:" ) + " " + eta ;
+
+	this->setWindowTitle( a + " : " + b ) ;
+
+	m_ui->progressBar->setValue( st ) ;
 }
 
 void createfile::pbOpenFolder()
